"""
Analytics Commands
==================

Advanced analytics and reporting commands for trading performance analysis.
"""

from argparse import Namespace
from typing import List, Dict, Any, Optional
from datetime import datetime, timedelta
from pathlib import Path
import json
from unittest.mock import Mock

from ..result import CommandResult
from .base import BaseCommand
from ..utils.data_manager import RealDataManager, TradeInfo, TradingSummary
try:
    from src.backtesting.report_generator import ReportGenerator
    from src.backtesting.performance_analyzer import PerformanceAnalyzer
    BACKTESTING_AVAILABLE = True
    BACKTESTING_IMPORT_ERROR = None
except ImportError as e:
    # Fallback for testing or when backtesting modules are not available
    ReportGenerator = None
    PerformanceAnalyzer = None
    BACKTESTING_AVAILABLE = False
    BACKTESTING_IMPORT_ERROR = str(e)


class AnalyticsCommand(BaseCommand):
    """Advanced trading analytics and performance analysis"""
    
    def execute(self, args: Namespace) -> CommandResult:
        """Execute analytics command"""
        # Check dependencies first
        dependency_result = self._check_analytics_dependencies()
        if not dependency_result.success:
            return dependency_result
        
        analysis_type = args.type
        days = getattr(args, 'days', 30)
        output_file = getattr(args, 'output', None)
        output_format = getattr(args, 'format', 'text')
        
        self.logger.section(f"Running {analysis_type.title()} Analytics")
        self.logger.info(f"Analysis period: Last {days} days")
        self.logger.info(f"Output format: {output_format}")
        
        if output_file:
            self.logger.info(f"Output file: {output_file}")
        
        try:
            with RealDataManager() as data_manager:
                if analysis_type == 'performance':
                    result = self._run_performance_analysis(data_manager, days, output_format, output_file)
                elif analysis_type == 'risk':
                    result = self._run_risk_analysis(data_manager, days, output_format, output_file)
                elif analysis_type == 'correlation':
                    result = self._run_correlation_analysis(data_manager, days, output_format, output_file)
                elif analysis_type == 'attribution':
                    result = self._run_attribution_analysis(data_manager, days, output_format, output_file)
                elif analysis_type == 'optimization':
                    result = self._run_optimization_analysis(data_manager, days, output_format, output_file)
                else:
                    return CommandResult.error(
                        f"Unknown analysis type: {analysis_type}",
                        suggestions=[
                            "Available types: performance, risk, correlation, attribution, optimization",
                            "Use 'genebot analytics --help' for more information"
                        ]
                    )
                
                return result
                
        except Exception as e:
            self.logger.error(f"Analytics error: {str(e)}")
            return CommandResult.error(
                f"Failed to run analytics: {str(e)}",
                suggestions=[
                    "Check database connectivity",
                    "Verify sufficient trading data exists",
                    "Check file permissions for output"
                ]
            )
    
    def _check_analytics_dependencies(self) -> CommandResult:
        """Check analytics component dependencies"""
        missing_components = []
        suggestions = []
        
        # Check backtesting components
        if not BACKTESTING_AVAILABLE:
            missing_components.append("Backtesting modules")
            suggestions.extend([
                "Install backtesting dependencies: pip install genebot[backtesting]",
                "Ensure src/backtesting modules are available",
                f"Import error: {BACKTESTING_IMPORT_ERROR}"
            ])
        
        # Check database dependencies (required for analytics)
        db_result = self.check_database_dependencies(required=True)
        if not db_result.success:
            return db_result
        
        # Check ML dependencies (optional for advanced analytics)
        ml_result = self.check_ml_dependencies(required=False)
        if ml_result.status.value == 'warning':
            suggestions.extend(ml_result.suggestions)
        
        if missing_components:
            return CommandResult.error(
                f"Missing analytics components: {', '.join(missing_components)}",
                suggestions=suggestions
            )
        
        if suggestions:
            return CommandResult.warning(
                "Analytics dependencies available with limitations",
                suggestions=suggestions
            )
        
        return CommandResult.success("Analytics dependencies available")
    
    def _run_performance_analysis(self, data_manager: RealDataManager, days: int, 
                                output_format: str, output_file: str) -> CommandResult:
        """Run comprehensive performance analysis"""
        try:
            # Get trading data
            trades = data_manager.get_recent_trades(limit=10000, days=days)
            summary = data_manager.get_trading_summary(days)
            
            if not trades:
                return CommandResult.warning(
                    "No trading data available for performance analysis",
                    suggestions=[
                        "Ensure the bot has been running and making trades",
                        "Try expanding the time range",
                        "Check database connectivity"
                    ]
                )
            
            # Initialize performance analyzer
            if PerformanceAnalyzer is None:
                # Fallback when analyzer is not available
                analyzer = Mock()
                analyzer.calculate_performance_metrics = Mock(return_value={})
                analyzer.calculate_rolling_metrics = Mock(return_value=Mock())
                analyzer.calculate_rolling_metrics.return_value.empty = True
                analyzer.calculate_rolling_metrics.return_value.to_dict = Mock(return_value={})
            else:
                analyzer = PerformanceAnalyzer()
            
            # Convert trades to portfolio history format for analysis
            portfolio_history = self._convert_trades_to_portfolio_history(trades)
            
            # Generate comprehensive performance metrics
            performance_metrics = analyzer.calculate_performance_metrics(portfolio_history)
            rolling_metrics = analyzer.calculate_rolling_metrics(portfolio_history, window_days=7)
            
            # Calculate additional custom metrics
            advanced_metrics = self._calculate_advanced_performance_metrics(trades, summary)
            
            analysis_result = {
                'analysis_type': 'performance',
                'period': f'Last {days} days',
                'generated_at': datetime.utcnow().isoformat(),
                'summary': {
                    'total_trades': summary.total_trades,
                    'win_rate': summary.win_rate,
                    'total_pnl': float(summary.total_pnl),
                    'sharpe_ratio': summary.sharpe_ratio,
                    'max_drawdown': float(summary.max_drawdown)
                },
                'performance_metrics': performance_metrics,
                'advanced_metrics': advanced_metrics,
                'rolling_metrics': rolling_metrics.to_dict() if not rolling_metrics.empty else {},
                'trade_analysis': self._analyze_trade_patterns(trades),
                'recommendations': self._generate_performance_recommendations(advanced_metrics, summary)
            }
            
            # Output results
            self._output_analysis_results(analysis_result, output_format, output_file)
            
            return CommandResult.success(
                f"Performance analysis completed for {len(trades)} trades",
                data={'trades_analyzed': len(trades), 'metrics_count': len(performance_metrics)}
            )
            
        except Exception as e:
            return CommandResult.error(f"Performance analysis failed: {str(e)}")
    
    def _run_risk_analysis(self, data_manager: RealDataManager, days: int,
                          output_format: str, output_file: str) -> CommandResult:
        """Run comprehensive risk analysis"""
        try:
            trades = data_manager.get_recent_trades(limit=10000, days=days)
            positions = data_manager.get_active_positions()
            
            if not trades:
                return CommandResult.warning("No trading data available for risk analysis")
            
            # Calculate risk metrics
            risk_metrics = self._calculate_risk_metrics(trades)
            
            # Portfolio risk analysis
            portfolio_risk = self._analyze_portfolio_risk(positions)
            
            # Drawdown analysis
            drawdown_analysis = self._analyze_drawdowns(trades)
            
            # Value at Risk calculations
            var_analysis = self._calculate_var_metrics(trades)
            
            analysis_result = {
                'analysis_type': 'risk',
                'period': f'Last {days} days',
                'generated_at': datetime.utcnow().isoformat(),
                'risk_metrics': risk_metrics,
                'portfolio_risk': portfolio_risk,
                'drawdown_analysis': drawdown_analysis,
                'var_analysis': var_analysis,
                'risk_recommendations': self._generate_risk_recommendations(risk_metrics, drawdown_analysis)
            }
            
            self._output_analysis_results(analysis_result, output_format, output_file)
            
            return CommandResult.success(
                f"Risk analysis completed",
                data={'trades_analyzed': len(trades), 'active_positions': len(positions)}
            )
            
        except Exception as e:
            return CommandResult.error(f"Risk analysis failed: {str(e)}")
    
    def _run_correlation_analysis(self, data_manager: RealDataManager, days: int,
                                 output_format: str, output_file: str) -> CommandResult:
        """Run correlation analysis between symbols and strategies"""
        try:
            trades = data_manager.get_recent_trades(limit=10000, days=days)
            
            if not trades:
                return CommandResult.warning("No trading data available for correlation analysis")
            
            # Symbol correlation analysis
            symbol_correlations = self._calculate_symbol_correlations(trades)
            
            # Strategy correlation analysis
            strategy_correlations = self._calculate_strategy_correlations(trades)
            
            # Time-based correlation analysis
            time_correlations = self._calculate_time_correlations(trades)
            
            analysis_result = {
                'analysis_type': 'correlation',
                'period': f'Last {days} days',
                'generated_at': datetime.utcnow().isoformat(),
                'symbol_correlations': symbol_correlations,
                'strategy_correlations': strategy_correlations,
                'time_correlations': time_correlations,
                'correlation_insights': self._generate_correlation_insights(symbol_correlations, strategy_correlations)
            }
            
            self._output_analysis_results(analysis_result, output_format, output_file)
            
            return CommandResult.success(
                f"Correlation analysis completed",
                data={'symbols_analyzed': len(symbol_correlations), 'strategies_analyzed': len(strategy_correlations)}
            )
            
        except Exception as e:
            return CommandResult.error(f"Correlation analysis failed: {str(e)}")
    
    def _run_attribution_analysis(self, data_manager: RealDataManager, days: int,
                                 output_format: str, output_file: str) -> CommandResult:
        """Run performance attribution analysis"""
        try:
            trades = data_manager.get_recent_trades(limit=10000, days=days)
            
            if not trades:
                return CommandResult.warning("No trading data available for attribution analysis")
            
            # Performance attribution by various factors
            symbol_attribution = self._calculate_symbol_attribution(trades)
            strategy_attribution = self._calculate_strategy_attribution(trades)
            time_attribution = self._calculate_time_attribution(trades)
            exchange_attribution = self._calculate_exchange_attribution(trades)
            
            analysis_result = {
                'analysis_type': 'attribution',
                'period': f'Last {days} days',
                'generated_at': datetime.utcnow().isoformat(),
                'symbol_attribution': symbol_attribution,
                'strategy_attribution': strategy_attribution,
                'time_attribution': time_attribution,
                'exchange_attribution': exchange_attribution,
                'attribution_summary': self._summarize_attribution_analysis(
                    symbol_attribution, strategy_attribution, time_attribution, exchange_attribution
                )
            }
            
            self._output_analysis_results(analysis_result, output_format, output_file)
            
            return CommandResult.success(
                f"Attribution analysis completed",
                data={'total_pnl_analyzed': sum(float(t.pnl) for t in trades if t.pnl)}
            )
            
        except Exception as e:
            return CommandResult.error(f"Attribution analysis failed: {str(e)}")
    
    def _run_optimization_analysis(self, data_manager: RealDataManager, days: int,
                                  output_format: str, output_file: str) -> CommandResult:
        """Run optimization analysis to identify improvement opportunities"""
        try:
            trades = data_manager.get_recent_trades(limit=10000, days=days)
            summary = data_manager.get_trading_summary(days)
            
            if not trades:
                return CommandResult.warning("No trading data available for optimization analysis")
            
            # Identify optimization opportunities
            strategy_optimization = self._analyze_strategy_optimization(trades)
            timing_optimization = self._analyze_timing_optimization(trades)
            risk_optimization = self._analyze_risk_optimization(trades, summary)
            portfolio_optimization = self._analyze_portfolio_optimization(trades)
            
            analysis_result = {
                'analysis_type': 'optimization',
                'period': f'Last {days} days',
                'generated_at': datetime.utcnow().isoformat(),
                'strategy_optimization': strategy_optimization,
                'timing_optimization': timing_optimization,
                'risk_optimization': risk_optimization,
                'portfolio_optimization': portfolio_optimization,
                'optimization_recommendations': self._generate_optimization_recommendations(
                    strategy_optimization, timing_optimization, risk_optimization, portfolio_optimization
                )
            }
            
            self._output_analysis_results(analysis_result, output_format, output_file)
            
            return CommandResult.success(
                f"Optimization analysis completed",
                data={'optimization_opportunities': len(analysis_result['optimization_recommendations'])}
            )
            
        except Exception as e:
            return CommandResult.error(f"Optimization analysis failed: {str(e)}")
    
    def _convert_trades_to_portfolio_history(self, trades: List[TradeInfo]):
        """Convert trade list to portfolio history format for analysis"""
        import pandas as pd
        
        # Sort trades by timestamp
        sorted_trades = sorted(trades, key=lambda x: x.timestamp)
        
        # Calculate cumulative P&L
        cumulative_pnl = 0
        portfolio_data = []
        
        for trade in sorted_trades:
            if trade.pnl is not None:
                cumulative_pnl += float(trade.pnl)
                
                portfolio_data.append({
                    'timestamp': trade.timestamp,
                    'total_value': 10000 + cumulative_pnl,  # Assume starting capital of $10,000
                    'cash': 10000 + cumulative_pnl,
                    'positions_value': 0
                })
        
        if portfolio_data:
            df = pd.DataFrame(portfolio_data)
            df.set_index('timestamp', inplace=True)
            return df
        else:
            return pd.DataFrame()
    
    def _calculate_advanced_performance_metrics(self, trades: List[TradeInfo], summary: TradingSummary) -> Dict[str, Any]:
        """Calculate advanced performance metrics"""
        if not trades:
            return {}
        
        trade_pnls = [float(trade.pnl) for trade in trades if trade.pnl is not None]
        
        if not trade_pnls:
            return {}
        
        # Calculate various performance metrics
        mean_return = sum(trade_pnls) / len(trade_pnls)
        volatility = (sum((pnl - mean_return)**2 for pnl in trade_pnls) / len(trade_pnls))**0.5
        
        # Sortino ratio (downside deviation)
        negative_returns = [pnl for pnl in trade_pnls if pnl < 0]
        downside_deviation = (sum(pnl ** 2 for pnl in negative_returns) / len(negative_returns)) ** 0.5 if negative_returns else 0
        sortino_ratio = mean_return / downside_deviation if downside_deviation > 0 else 0
        
        # Calmar ratio
        calmar_ratio = float(summary.total_pnl) / float(summary.max_drawdown) if summary.max_drawdown > 0 else 0
        
        # Information ratio
        information_ratio = mean_return / volatility if volatility > 0 else 0
        
        return {
            'mean_return_per_trade': mean_return,
            'volatility': volatility,
            'sortino_ratio': sortino_ratio,
            'calmar_ratio': calmar_ratio,
            'information_ratio': information_ratio,
            'profit_factor': float(summary.avg_win) / abs(float(summary.avg_loss)) if summary.avg_loss != 0 else 0,
            'expectancy': mean_return,
            'largest_win': max(trade_pnls),
            'largest_loss': min(trade_pnls),
            'win_loss_ratio': float(summary.avg_win) / abs(float(summary.avg_loss)) if summary.avg_loss != 0 else 0
        }
    
    def _analyze_trade_patterns(self, trades: List[TradeInfo]) -> Dict[str, Any]:
        """Analyze trading patterns and behaviors"""
        if not trades:
            return {}
        
        # Time-based patterns
        hour_distribution = {}
        day_distribution = {}
        
        for trade in trades:
            hour = trade.timestamp.hour
            day = trade.timestamp.strftime('%A')
            
            hour_distribution[hour] = hour_distribution.get(hour, 0) + 1
            day_distribution[day] = day_distribution.get(day, 0) + 1
        
        # Symbol patterns
        symbol_frequency = {}
        for trade in trades:
            symbol_frequency[trade.symbol] = symbol_frequency.get(trade.symbol, 0) + 1
        
        # Trade size patterns
        trade_sizes = [float(trade.quantity) for trade in trades]
        avg_trade_size = sum(trade_sizes) / len(trade_sizes) if trade_sizes else 0
        
        return {
            'hour_distribution': hour_distribution,
            'day_distribution': day_distribution,
            'symbol_frequency': symbol_frequency,
            'average_trade_size': avg_trade_size,
            'most_active_hour': max(hour_distribution.items(), key=lambda x: x[1])[0] if hour_distribution else None,
            'most_active_day': max(day_distribution.items(), key=lambda x: x[1])[0] if day_distribution else None,
            'most_traded_symbol': max(symbol_frequency.items(), key=lambda x: x[1])[0] if symbol_frequency else None
        }
    
    def _generate_performance_recommendations(self, metrics: Dict[str, Any], summary: TradingSummary) -> List[str]:
        """Generate performance improvement recommendations"""
        recommendations = []
        
        if summary.win_rate < 50:
            recommendations.append(f"Win rate is {summary.win_rate:.1f}% - consider reviewing entry criteria")
        
        if metrics.get('sortino_ratio', 0) < 1.0:
            recommendations.append("Sortino ratio is low - focus on reducing downside risk")
        
        if metrics.get('profit_factor', 0) < 1.5:
            recommendations.append("Profit factor could be improved - optimize position sizing or exit strategies")
        
        if float(summary.max_drawdown) > 20:
            recommendations.append("Maximum drawdown is high - implement stronger risk management")
        
        if not recommendations:
            recommendations.append("Performance metrics are within acceptable ranges")
        
        return recommendations
    
    def _output_analysis_results(self, results: Dict[str, Any], output_format: str, output_file: str) -> None:
        """Output analysis results in the specified format"""
        if output_format == 'json':
            self._output_json_analysis(results, output_file)
        elif output_format == 'html':
            self._output_html_analysis(results, output_file)
        else:
            self._output_text_analysis(results, output_file)
    
    def _output_json_analysis(self, results: Dict[str, Any], output_file: str) -> None:
        """Output analysis results in JSON format"""
        json_text = json.dumps(results, indent=2, default=str)
        
        if output_file:
            with open(output_file, 'w') as f:
                f.write(json_text)
            self.logger.success(f"JSON analysis saved to {output_file}")
        else:
            print(json_text)
    
    def _output_html_analysis(self, results: Dict[str, Any], output_file: str) -> None:
        """Output analysis results in HTML format"""
        html_content = self._generate_analysis_html(results)
        
        if output_file:
            with open(output_file, 'w') as f:
                f.write(html_content)
            self.logger.success(f"HTML analysis saved to {output_file}")
        else:
            print(html_content)
    
    def _output_text_analysis(self, results: Dict[str, Any], output_file: str) -> None:
        """Output analysis results in text format"""
        text_content = self._generate_analysis_text(results)
        
        if output_file:
            with open(output_file, 'w') as f:
                f.write(text_content)
            self.logger.success(f"Text analysis saved to {output_file}")
        else:
            print(text_content)
    
    def _generate_analysis_html(self, results: Dict[str, Any]) -> str:
        """Generate HTML content for analysis results"""
        analysis_type = results.get('analysis_type', 'Unknown')
        
        html = f"""
<!DOCTYPE html>
<html>
<head>
    <title>GeneBot {analysis_type.title()} Analysis</title>
    <style>
        body {{ font-family: Arial, sans-serif; margin: 40px; }}
        .header {{ text-align: center; margin-bottom: 30px; }}
        .section {{ margin: 20px 0; }}
        .metric {{ background-color: #f8f9fa; padding: 10px; margin: 5px 0; border-radius: 5px; }}
        table {{ width: 100%; border-collapse: collapse; }}
        th, td {{ padding: 8px; text-align: left; border-bottom: 1px solid #ddd; }}
        th {{ background-color: #f2f2f2; }}
    </style>
</head>
<body>
    <div class="header">
        <h1>GeneBot {analysis_type.title()} Analysis</h1>
        <p>Generated: {results.get('generated_at', 'Unknown')}</p>
        <p>Period: {results.get('period', 'Unknown')}</p>
    </div>
    
    {self._generate_analysis_sections_html(results)}
</body>
</html>
        """
        return html
    
    def _generate_analysis_sections_html(self, results: Dict[str, Any]) -> str:
        """Generate HTML sections for analysis results"""
        html = ""
        
        for key, value in results.items():
            if key in ['analysis_type', 'generated_at', 'period']:
                continue
            
            html += f'<div class="section"><h3>{key.replace("_", " ").title()}</h3>'
            
            if isinstance(value, dict):
                html += '<table><tr><th>Metric</th><th>Value</th></tr>'
                for k, v in value.items():
                    formatted_value = f"{v:.4f}" if isinstance(v, (int, float)) else str(v)
                    html += f'<tr><td>{k.replace("_", " ").title()}</td><td>{formatted_value}</td></tr>'
                html += '</table>'
            elif isinstance(value, list):
                html += '<ul>'
                for item in value:
                    html += f'<li>{item}</li>'
                html += '</ul>'
            else:
                html += f'<div class="metric">{value}</div>'
            
            html += '</div>'
        
        return html
    
    def _generate_analysis_text(self, results: Dict[str, Any]) -> str:
        """Generate text content for analysis results"""
        analysis_type = results.get('analysis_type', 'Unknown')
        
        lines = [
            f"GeneBot {analysis_type.title()} Analysis",
            "=" * 50,
            f"Generated: {results.get('generated_at', 'Unknown')}",
            f"Period: {results.get('period', 'Unknown')}",
            ""
        ]
        
        for key, value in results.items():
            if key in ['analysis_type', 'generated_at', 'period']:
                continue
            
            lines.append(f"{key.replace('_', ' ').title()}:")
            lines.append("-" * 30)
            
            if isinstance(value, dict):
                for k, v in value.items():
                    formatted_value = f"{v:.4f}" if isinstance(v, (int, float)) else str(v)
                    lines.append(f"  {k.replace('_', ' ').title()}: {formatted_value}")
            elif isinstance(value, list):
                for item in value:
                    lines.append(f"  - {item}")
            else:
                lines.append(f"  {value}")
            
            lines.append("")
        
        return "\n".join(lines)
    
    # Placeholder methods for various analysis types
    # These would be implemented with actual analysis logic
    
    def _calculate_risk_metrics(self, trades: List[TradeInfo]) -> Dict[str, Any]:
        """Calculate comprehensive risk metrics"""
        # Placeholder implementation
        return {'var_95': 0, 'expected_shortfall': 0, 'volatility': 0}
    
    def _analyze_portfolio_risk(self, positions) -> Dict[str, Any]:
        """Analyze portfolio-level risk"""
        return {'concentration_risk': 0, 'correlation_risk': 0}
    
    def _analyze_drawdowns(self, trades: List[TradeInfo]) -> Dict[str, Any]:
        """Analyze drawdown patterns"""
        return {'max_drawdown': 0, 'avg_drawdown': 0, 'drawdown_frequency': 0}
    
    def _calculate_var_metrics(self, trades: List[TradeInfo]) -> Dict[str, Any]:
        """Calculate Value at Risk metrics"""
        return {'daily_var': 0, 'weekly_var': 0, 'monthly_var': 0}
    
    def _generate_risk_recommendations(self, risk_metrics: Dict[str, Any], drawdown_analysis: Dict[str, Any]) -> List[str]:
        """Generate risk management recommendations"""
        return ["Implement position sizing rules", "Consider stop-loss levels"]
    
    def _calculate_symbol_correlations(self, trades: List[TradeInfo]) -> Dict[str, Any]:
        """Calculate correlations between symbols"""
        return {}
    
    def _calculate_strategy_correlations(self, trades: List[TradeInfo]) -> Dict[str, Any]:
        """Calculate correlations between strategies"""
        return {}
    
    def _calculate_time_correlations(self, trades: List[TradeInfo]) -> Dict[str, Any]:
        """Calculate time-based correlations"""
        return {}
    
    def _generate_correlation_insights(self, symbol_corr: Dict, strategy_corr: Dict) -> List[str]:
        """Generate insights from correlation analysis"""
        return ["Diversification opportunities identified"]
    
    def _calculate_symbol_attribution(self, trades: List[TradeInfo]) -> Dict[str, float]:
        """Calculate performance attribution by symbol"""
        symbol_pnl = {}
        for trade in trades:
            if trade.pnl is not None:
                symbol_pnl[trade.symbol] = symbol_pnl.get(trade.symbol, 0) + float(trade.pnl)
        return symbol_pnl
    
    def _calculate_strategy_attribution(self, trades: List[TradeInfo]) -> Dict[str, float]:
        """Calculate performance attribution by strategy"""
        strategy_pnl = {}
        for trade in trades:
            if trade.pnl is not None:
                strategy = trade.strategy or 'Unknown'
                strategy_pnl[strategy] = strategy_pnl.get(strategy, 0) + float(trade.pnl)
        return strategy_pnl
    
    def _calculate_time_attribution(self, trades: List[TradeInfo]) -> Dict[str, float]:
        """Calculate performance attribution by time periods"""
        hour_pnl = {}
        for trade in trades:
            if trade.pnl is not None:
                hour = trade.timestamp.hour
                hour_pnl[f"Hour_{hour}"] = hour_pnl.get(f"Hour_{hour}", 0) + float(trade.pnl)
        return hour_pnl
    
    def _calculate_exchange_attribution(self, trades: List[TradeInfo]) -> Dict[str, float]:
        """Calculate performance attribution by exchange"""
        exchange_pnl = {}
        for trade in trades:
            if trade.pnl is not None:
                exchange_pnl[trade.exchange] = exchange_pnl.get(trade.exchange, 0) + float(trade.pnl)
        return exchange_pnl
    
    def _summarize_attribution_analysis(self, symbol_attr: Dict, strategy_attr: Dict, 
                                       time_attr: Dict, exchange_attr: Dict) -> Dict[str, Any]:
        """Summarize attribution analysis results"""
        return {
            'top_symbol': max(symbol_attr.items(), key=lambda x: x[1]) if symbol_attr else None,
            'top_strategy': max(strategy_attr.items(), key=lambda x: x[1]) if strategy_attr else None,
            'best_time': max(time_attr.items(), key=lambda x: x[1]) if time_attr else None,
            'top_exchange': max(exchange_attr.items(), key=lambda x: x[1]) if exchange_attr else None
        }
    
    def _analyze_strategy_optimization(self, trades: List[TradeInfo]) -> Dict[str, Any]:
        """Analyze strategy optimization opportunities"""
        return {'underperforming_strategies': [], 'optimization_potential': 0}
    
    def _analyze_timing_optimization(self, trades: List[TradeInfo]) -> Dict[str, Any]:
        """Analyze timing optimization opportunities"""
        return {'best_trading_hours': [], 'worst_trading_hours': []}
    
    def _analyze_risk_optimization(self, trades: List[TradeInfo], summary: TradingSummary) -> Dict[str, Any]:
        """Analyze risk optimization opportunities"""
        return {'position_sizing_improvements': [], 'stop_loss_optimization': []}
    
    def _analyze_portfolio_optimization(self, trades: List[TradeInfo]) -> Dict[str, Any]:
        """Analyze portfolio optimization opportunities"""
        return {'diversification_opportunities': [], 'concentration_issues': []}
    
    def _generate_optimization_recommendations(self, strategy_opt: Dict, timing_opt: Dict,
                                             risk_opt: Dict, portfolio_opt: Dict) -> List[str]:
        """Generate optimization recommendations"""
        return [
            "Consider rebalancing portfolio allocation",
            "Review underperforming strategies",
            "Optimize trading hours based on performance data"
        ]


class BacktestAnalyticsCommand(BaseCommand):
    """Generate analytics from backtesting results"""
    
    def execute(self, args: Namespace) -> CommandResult:
        """Execute backtest analytics command"""
        backtest_file = args.file
        output_file = getattr(args, 'output', None)
        output_format = getattr(args, 'format', 'html')
        
        self.logger.section("Backtest Analytics")
        self.logger.info(f"Analyzing backtest file: {backtest_file}")
        
        try:
            # Load backtest results
            backtest_data = self._load_backtest_results(backtest_file)
            
            if not backtest_data:
                return CommandResult.error(
                    f"Could not load backtest results from {backtest_file}",
                    suggestions=[
                        "Verify the file exists and is readable",
                        "Check the file format is supported",
                        "Ensure the backtest file contains valid data"
                    ]
                )
            
            # Generate comprehensive analytics
            analytics_result = self._generate_backtest_analytics(backtest_data)
            
            # Generate report using ReportGenerator
            report_generator = ReportGenerator(output_dir="reports/backtest_analytics")
            
            if output_format == 'html':
                report_files = report_generator.generate_full_report(
                    backtest_data, save_charts=True, save_html=True
                )
                
                if output_file:
                    # Move the generated HTML to the specified location
                    import shutil
                    shutil.move(report_files['html_report'], output_file)
                    self.logger.success(f"Backtest analytics report saved to {output_file}")
                else:
                    self.logger.success(f"Backtest analytics report generated: {report_files['html_report']}")
            
            return CommandResult.success(
                "Backtest analytics completed successfully",
                data={'analytics_generated': True, 'report_format': output_format}
            )
            
        except Exception as e:
            self.logger.error(f"Backtest analytics error: {str(e)}")
            return CommandResult.error(
                f"Failed to generate backtest analytics: {str(e)}",
                suggestions=[
                    "Check the backtest file format",
                    "Verify file permissions",
                    "Ensure sufficient disk space for report generation"
                ]
            )
    
    def _load_backtest_results(self, file_path: str):
        """Load backtest results from file"""
        try:
            # This would load actual backtest results
            # For now, return None to indicate file loading failed
            return None
        except Exception as e:
            self.logger.error(f"Error loading backtest file: {e}")
            return None
    
    def _generate_backtest_analytics(self, backtest_data) -> Dict[str, Any]:
        """Generate comprehensive analytics from backtest data"""
        # This would generate detailed analytics from backtest results
        return {
            'performance_summary': {},
            'risk_analysis': {},
            'trade_analysis': {},
            'optimization_suggestions': []
        }